@@ -511,7 +511,7 @@ sub make_setup_recipe {
 # standardized Setup.hs file. For more information, see
 # https://www.haskell.org/cabal/users-guide/developing-packages.html#pkg-field-build-type
 
-    my $cabal_path = "$ENV{CABAL_PACKAGE}.cabal";
+    my $cabal_path = (glob("*.cabal"))[0];
     my $cabal_contents = path($cabal_path)->slurp_utf8;
 
     die encode_utf8("No cabal-version in $cabal_path")
@@ -567,7 +567,9 @@ sub configure_recipe {
     run(
         qw{find . ! -newer},
         $time_reference->stringify,
-        qw{-exec touch -d "1998-01-01 UTC" {} ; }
+        qw{-exec touch -d},
+        '1998-01-01 UTC',
+        qw{{} ; }
     );
 
     my $compiler = source_hc() || $ENV{DEB_DEFAULT_COMPILER};
